/*
 *   Copyright (C) 2014  Alfons Wirtz
 *   website www.freerouting.net
 *
 *   Copyright (C) 2017 Michael Hoffer <info@michaelhoffer.de>
 *   Website www.freerouting.mihosoft.eu
 *
 *   Copyright (C) 2021 Erich S. Heinzle
 *   Website http://www.repo.hu/projects/freerouting_cli/
 */

package eu.mihosoft.freerouting.logger;

import eu.mihosoft.freerouting.FreeRouting;

import java.text.DecimalFormat;
import java.time.Duration;
import java.time.Instant;
import java.util.HashMap;

public class FRLogger {
    //private static Logger logger = LogManager.getLogger(FreeRouting.class);

    private static DecimalFormat performanceFormat = new DecimalFormat("0.00");

    private static HashMap<Integer, Instant> perfData = new HashMap<Integer, Instant>();

    private static TraceLevel trace_level = TraceLevel.NO_DEBUGGING_OUTPUT;

    public static void traceEntry(String perfId)
    {
        perfData.put(perfId.hashCode(), java.time.Instant.now());
    }

    public static void traceExit(String perfId)
    {
        traceExit(perfId, null);
    }

    public static void traceExit(String perfId, Object result)
    {
        long timeElapsed = Duration.between(perfData.get(perfId.hashCode()), java.time.Instant.now()).toMillis();

        perfData.remove(perfId.hashCode());
        if (timeElapsed < 0) {
            timeElapsed = 0;
        }
        System.out.println("--FRCLI--TRACE--Method '" + perfId.replace("{}", result != null ? result.toString() : "(null)") + "' was performed in " + performanceFormat.format(timeElapsed/1000.0) + " seconds.");
    }

    public static void info(String msg)
    {
        System.out.println("--FRCLI--INFO--" + msg);
    }

    public static void warn(String msg)
    {
        System.out.println("--FRCLI--WARN--" + msg);
    }

    public static void debug(String msg)
    {
        if (trace_level != TraceLevel.NO_DEBUGGING_OUTPUT)
        {
            System.out.println("--FRCLI--DEBUG--" + msg);
        }
    }

    public static void validate(String msg)
    {
        if (trace_level != TraceLevel.NO_DEBUGGING_OUTPUT)
        {
            System.out.println("--FRCLI--VALIDATE--" + msg);
        }
    }

    public static void progress(String msg, int count, int total)
    {
	System.out.println("--FRCLI--PROGRESS--" + msg + ": " + count + "/" + total);
    }
    public static void error(String msg, Throwable t)
    {
        if (t == null)
        {
            System.out.println("--FRCLI--ERROR--" + msg);
        } else
        {
            System.out.println("--FRCLI--ERROR--" + msg + " : " + t);
        }
    }

    public static void setTraceLevelNone()
    {
        trace_level = TraceLevel.NO_DEBUGGING_OUTPUT;
        info("FRLogger verbosity: NO_DEBUGGING_OUTPUT");
    }

    public static void setTraceLevelCritical()
    {
        trace_level = TraceLevel.CRITICAL_DEBUGGING_OUTPUT;
        info("FRLogger verbosity: CRITICAL_DEBUGGING_OUTPUT");
    }

    public static void setTraceLevelAll()
    {
        trace_level = TraceLevel.ALL_DEBUGGING_OUTPUT;
        info("FRLogger verbosity: ALL_DEBUGGING_OUTPUT");
    }

    public static boolean allDebuggingOutput()
    {
        return trace_level == TraceLevel.ALL_DEBUGGING_OUTPUT;
    }

    private static enum TraceLevel
    {
        NO_DEBUGGING_OUTPUT, CRITICAL_DEBUGGING_OUTPUT, ALL_DEBUGGING_OUTPUT
    }

}
